Montblanc
=========

A `Tensorflow <https://www.tensorflow.org/>`_ implementation
of the Radio Interferometry Measurement Equation,
and a foothill of Mount Exaflop.

License
-------

Montblanc is licensed under the GNU GPL v2.0 License.

Documentation
-------------

Available on `readthedocs <https://montblanc.readthedocs.io/>`_